cgexplore.systems\_optimisation.Chromosome
==========================================

.. currentmodule:: cgexplore.systems_optimisation

.. autoclass:: Chromosome
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Chromosome.get_building_blocks
      ~Chromosome.get_forcefield
      ~Chromosome.get_precursors
      ~Chromosome.get_separated_string
      ~Chromosome.get_string
      ~Chromosome.get_topology_information
      ~Chromosome.get_vertex_alignments
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Chromosome.name
      ~Chromosome.present_beads
      ~Chromosome.vdw_bond_cutoff
      ~Chromosome.prefix
      ~Chromosome.gene_dict
      ~Chromosome.definer_dict
      ~Chromosome.chromosomed_terms
   
   